@@ -1,9 +1,12 @@
 import random
 import keras
 import numpy as np
-from .layers import (get_inputs, Embeddings, Transformer, Attention, MultiHeadAttention,
-                     FeedForward, Masked, Extract, LayerNormalization)
-from .activations import gelu
+import tensorflow as tf
+from keras_pos_embd import PositionEmbedding
+from keras_layer_normalization import LayerNormalization
+from keras_transformer import get_encoders
+from keras_transformer import get_custom_objects as get_encoder_custom_objects
+from .layers import (get_inputs, get_embedding, TokenEmbedding, EmbeddingSimilarity, Masked, Extract)
 
 
 TOKEN_PAD = ''  # Token for padding
@@ -13,6 +16,10 @@ TOKEN_SEP = '<SEP>'  # Token for separation
 TOKEN_MASK = '<MASK>'  # Token for masking
 
 
+def gelu(x):
+    return 0.5 * x * (1.0 + tf.erf(x / tf.sqrt(2.0)))
+
+
 def get_model(token_num,
               pos_num=512,
               seq_len=512,
@@ -21,6 +28,10 @@ def get_model(token_num,
               head_num=12,
               feed_forward_dim=3072,
               dropout_rate=0.1,
+              attention_activation=None,
+              feed_forward_activation=gelu,
+              custom_layers=None,
+              training=True,
               lr=1e-4):
     """Get BERT model.
 
@@ -34,37 +45,61 @@ def get_model(token_num,
     :param head_num: Number of heads in multi-head attention in each transformer.
     :param feed_forward_dim: Dimension of the feed forward layer in each transformer.
     :param dropout_rate: Dropout rate.
+    :param attention_activation: Activation for attention layers.
+    :param feed_forward_activation: Activation for feed-forward layers.
+    :param custom_layers: A function that takes the embedding tensor and returns the tensor after feature extraction.
+                          Arguments such as `transformer_num` and `head_num` will be ignored if `custom_layer` is not
+                          `None`.
+    :param training: The built model will be returned if it is `True`, otherwise the input layers and the last feature
+                     extraction layer will be returned.
     :param lr: Learning rate.
     :return: The compiled model.
     """
     inputs = get_inputs(seq_len=seq_len)
-    embed_layer = Embeddings(
-        input_dim=token_num,
-        output_dim=embed_dim,
-        position_dim=pos_num,
+    embed_layer, embed_weights = get_embedding(
+        inputs,
+        token_num=token_num,
+        embed_dim=embed_dim,
+        pos_num=pos_num,
         dropout_rate=dropout_rate,
-        name='Embeddings',
-    )(inputs[:3])
+    )
     transformed = embed_layer
-    for i in range(transformer_num):
-        transformed = Transformer(
+    if custom_layers is not None:
+        kwargs = {}
+        if keras.utils.generic_utils.has_arg(custom_layers, 'trainable'):
+            kwargs['trainable'] = training
+        transformed = custom_layers(transformed, **kwargs)
+    else:
+        transformed = get_encoders(
+            encoder_num=transformer_num,
+            input_layer=transformed,
             head_num=head_num,
             hidden_dim=feed_forward_dim,
+            attention_activation=attention_activation,
+            feed_forward_activation=feed_forward_activation,
             dropout_rate=dropout_rate,
-            name='Transformer-%d' % (i + 1),
-        )(transformed)
-    mlm_pred_layer = keras.layers.Dense(
-        units=token_num,
-        activation='softmax',
-        name='Dense-MLM',
+        )
+    if not training:
+        return inputs[:2], transformed
+    mlm_dense_layer = keras.layers.Dense(
+        units=embed_dim,
+        activation=feed_forward_activation,
+        name='MLM-Dense',
     )(transformed)
+    mlm_norm_layer = LayerNormalization(name='MLM-Norm')(mlm_dense_layer)
+    mlm_pred_layer = EmbeddingSimilarity(name='MLM-Sim')([mlm_norm_layer, embed_weights])
     masked_layer = Masked(name='MLM')([mlm_pred_layer, inputs[-1]])
     extract_layer = Extract(index=0, name='Extract')(transformed)
+    nsp_dense_layer = keras.layers.Dense(
+        units=embed_dim,
+        activation='tanh',
+        name='NSP-Dense',
+    )(extract_layer)
     nsp_pred_layer = keras.layers.Dense(
         units=2,
         activation='softmax',
         name='NSP',
-    )(extract_layer)
+    )(nsp_dense_layer)
     model = keras.models.Model(inputs=inputs, outputs=[masked_layer, nsp_pred_layer])
     model.compile(
         optimizer=keras.optimizers.Adam(lr=lr),
@@ -76,17 +111,14 @@ def get_model(token_num,
 
 def get_custom_objects():
     """Get all custom objects for loading saved models."""
-    return {
-        'Embeddings': Embeddings,
-        'Attention': Attention,
-        'MultiHeadAttention': MultiHeadAttention,
-        'FeedForward': FeedForward,
-        'LayerNormalization': LayerNormalization,
-        'Transformer': Transformer,
-        'Masked': Masked,
-        'Extract': Extract,
-        'gelu': gelu,
-    }
+    custom_objects = get_encoder_custom_objects()
+    custom_objects['PositionEmbedding'] = PositionEmbedding
+    custom_objects['TokenEmbedding'] = TokenEmbedding
+    custom_objects['EmbeddingSimilarity'] = EmbeddingSimilarity
+    custom_objects['Masked'] = Masked
+    custom_objects['Extract'] = Extract
+    custom_objects['gelu'] = gelu
+    return custom_objects
 
 
 def get_base_dict():
@@ -107,7 +139,8 @@ def gen_batch_inputs(sentence_pairs,
                      mask_rate=0.15,
                      mask_mask_rate=0.8,
                      mask_random_rate=0.1,
-                     swap_sentence_rate=0.5):
+                     swap_sentence_rate=0.5,
+                     force_mask=True):
     """Generate a batch of inputs and outputs for training.
 
     :param sentence_pairs: A list of pairs containing lists of tokens.
@@ -118,13 +151,14 @@ def gen_batch_inputs(sentence_pairs,
     :param mask_mask_rate: The rate of replacing the token to `TOKEN_MASK`.
     :param mask_random_rate: The rate of replacing the token to a random word.
     :param swap_sentence_rate: The rate of swapping the second sentences.
+    :param force_mask: At least one position will be masked.
     :return: All the inputs and outputs.
     """
     batch_size = len(sentence_pairs)
     base_dict = get_base_dict()
     unknown_index = token_dict[TOKEN_UNK]
     # Generate sentence swapping mapping
-    nsp_outputs = np.ones((batch_size,))
+    nsp_outputs = np.zeros((batch_size,))
     mapping = {}
     if swap_sentence_rate > 0.0:
         indices = [index for index in range(batch_size) if random.random() < swap_sentence_rate]
@@ -132,9 +166,8 @@ def gen_batch_inputs(sentence_pairs,
         random.shuffle(mapped)
         for i in range(len(mapped)):
             if indices[i] != mapped[i]:
-                nsp_outputs[indices[i]] = 0.0
+                nsp_outputs[indices[i]] = 1.0
         mapping = {indices[i]: mapped[i] for i in range(len(indices))}
-    position_inputs = [[i for i in range(seq_len)] for _ in range(batch_size)]
     # Generate MLM
     token_inputs, segment_inputs, masked_inputs = [], [], []
     mlm_outputs = []
@@ -165,11 +198,11 @@ def gen_batch_inputs(sentence_pairs,
             else:
                 masked_input.append(0)
                 token_input.append(token_dict.get(token, unknown_index))
-        if not has_mask:  # Used to prevent nan loss
+        if force_mask and not has_mask:
             masked_input[1] = 1
         token_inputs.append(token_input)
         masked_inputs.append(masked_input)
         mlm_outputs.append(mlm_output)
-    inputs = [np.asarray(x) for x in [token_inputs, segment_inputs, position_inputs, masked_inputs]]
+    inputs = [np.asarray(x) for x in [token_inputs, segment_inputs, masked_inputs]]
     outputs = [np.asarray(np.expand_dims(x, axis=-1)) for x in [mlm_outputs, nsp_outputs]]
     return inputs, outputs
