@@ -4,7 +4,7 @@ import tempfile
 import random
 import keras
 import numpy as np
-from keras_bert import get_model, get_custom_objects, get_base_dict, gen_batch_inputs
+from keras_bert import gelu, get_model, get_custom_objects, get_base_dict, gen_batch_inputs
 
 
 class TestBERT(unittest.TestCase):
@@ -52,6 +52,7 @@ class TestBERT(unittest.TestCase):
                 seq_len=20,
                 pos_num=20,
                 dropout_rate=0.05,
+                attention_activation=gelu,
                 lr=1e-3,
             )
         model.summary()
@@ -74,10 +75,11 @@ class TestBERT(unittest.TestCase):
             validation_data=_generator(),
             validation_steps=100,
             callbacks=[
+                keras.callbacks.ReduceLROnPlateau(monitor='val_MLM_loss', factor=0.5, patience=3),
                 keras.callbacks.EarlyStopping(monitor='val_MLM_loss', patience=5)
             ],
         )
-        model.save(model_path)
+        # model.save(model_path)
         for inputs, outputs in _generator():
             predicts = model.predict(inputs)
             outputs = list(map(lambda x: np.squeeze(x, axis=-1), outputs))
@@ -89,3 +91,27 @@ class TestBERT(unittest.TestCase):
                         self.assertEqual(outputs[0][i][j], predicts[0][i][j])
             self.assertTrue(np.allclose(outputs[1], predicts[1]))
             break
+
+    def test_get_layers(self):
+
+        def _custom_layers(x, trainable=True):
+            return keras.layers.LSTM(
+                units=768,
+                trainable=trainable,
+                name='LSTM',
+            )(x)
+
+        inputs, output_layer = get_model(
+            token_num=200,
+            embed_dim=768,
+            custom_layers=_custom_layers,
+            training=False,
+        )
+        model = keras.models.Model(inputs=inputs, outputs=output_layer)
+        model.compile(
+            optimizer='adam',
+            loss='mse',
+            metrics={},
+        )
+        model.summary()
+        self.assertTrue(model is not None)
